@@ -85,8 +85,8 @@ int main(int argc, char **argv)
       leftCorner.hide();
       rightCorner.hide();
    }
-   leftCorner.connect( mainBAB->cornerCheck, SIGNAL(toggled(bool)), SLOT(toggle(bool)) );
-   rightCorner.connect( mainBAB->cornerCheck, SIGNAL(toggled(bool)), SLOT(toggle(bool)) );
+   leftCorner.connect( mainBAB->cornerCheck, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggle(bool)) );
+   rightCorner.connect( mainBAB->cornerCheck, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggle(bool)) );
 
    int ret = app.exec();
    if (mainBAB) delete mainBAB;
@@ -177,11 +177,11 @@ bab::bab() : TDEMainWindow(0,"bab",TQt::WStyle_StaysOnTop | TQt::WX11BypassWM ){
    bSwitcher->setStyle(DefStyle->currentText());
    bSwitcher->setDeco(DefStyle->currentText());
    
-   connect(DefStyle, SIGNAL(activated(int)), this, SLOT(saveSettings()));
-   connect(cornerCheck, SIGNAL(toggled(bool)), this, SLOT(saveSettings()));
-   connect(configBaghira, SIGNAL(clicked()), this, SLOT(configureBaghira()));
-   connect(Close, SIGNAL(clicked()), this, SLOT(hide()));
-   connect(Quit, SIGNAL(clicked()), this, SLOT(close()));
+   connect(DefStyle, TQ_SIGNAL(activated(int)), this, TQ_SLOT(saveSettings()));
+   connect(cornerCheck, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(saveSettings()));
+   connect(configBaghira, TQ_SIGNAL(clicked()), this, TQ_SLOT(configureBaghira()));
+   connect(Close, TQ_SIGNAL(clicked()), this, TQ_SLOT(hide()));
+   connect(Quit, TQ_SIGNAL(clicked()), this, TQ_SLOT(close()));
    
    resize(vb->width(),vb->height());
    
@@ -261,12 +261,12 @@ void bab::configureBaghira()
    TQPoint nPos((desktop->width() - dial->width())/2, (desktop->height() - dial->height() - 100)/2);
    dial->move(nPos);
 	//..and connect it to the wrapper
-   connect(styleConfig, SIGNAL(changed(bool)), dial, SLOT(setStyleDirty(bool)));
-   connect(decoObject, SIGNAL(changed()), dial, SLOT(setDecoDirty()));
-   connect(dial, SIGNAL(defaults()), styleConfig, SLOT(defaults()));
-   connect(dial, SIGNAL(save()), styleConfig, SLOT(save()));
-   connect(dial, SIGNAL(defaults()), decoObject, SLOT(defaults()));
-   connect(dial, SIGNAL(save(TDEConfig*)), decoObject, SLOT(save(TDEConfig*)));
+   connect(styleConfig, TQ_SIGNAL(changed(bool)), dial, TQ_SLOT(setStyleDirty(bool)));
+   connect(decoObject, TQ_SIGNAL(changed()), dial, TQ_SLOT(setDecoDirty()));
+   connect(dial, TQ_SIGNAL(defaults()), styleConfig, TQ_SLOT(defaults()));
+   connect(dial, TQ_SIGNAL(save()), styleConfig, TQ_SLOT(save()));
+   connect(dial, TQ_SIGNAL(defaults()), decoObject, TQ_SLOT(defaults()));
+   connect(dial, TQ_SIGNAL(save(TDEConfig*)), decoObject, TQ_SLOT(save(TDEConfig*)));
    
    if (dial->exec() == TQDialog::Accepted)
    {
