@@ -969,7 +969,7 @@ void tdestyle_baghira_config::menuToggled(bool active)
 
 extern "C"
 {
-    KDE_EXPORT TQWidget* allocate_tdestyle_config(TQWidget* parent){
+    TDE_EXPORT TQWidget* allocate_tdestyle_config(TQWidget* parent){
          return(new tdestyle_baghira_config(parent, "BaghiraConfig"));
     }
 }
