@@ -132,7 +132,7 @@ Atom baghira_deco_design = XInternAtom(tqt_xdisplay(), "BAGHIRA_DECO_DESIGN", Fa
 
 extern "C"
 {
-	KDE_EXPORT KDecorationFactory* create_factory()
+	TDE_EXPORT KDecorationFactory* create_factory()
 	{
 		return new Baghira::BaghiraFactory();
 	}
