@@ -61,7 +61,7 @@ extern Time tqt_x_time;
 
 extern "C"
 {
-    KDE_EXPORT KPanelApplet* init( TQWidget* parent_P, const TQString& configFile_P )
+    TDE_EXPORT KPanelApplet* init( TQWidget* parent_P, const TQString& configFile_P )
     {
       TDEGlobal::locale()->insertCatalogue("baghira-kmenuapplet");
       return new KickerMenuApplet::Applet( configFile_P, parent_P );
