@@ -46,7 +46,7 @@ void baghiraSidebar::handleURL(const KURL &url)
 }
 
 extern "C" {
-   KDE_EXPORT bool add_konqsidebar_baghirasidebar(TQString* fn, TQString* param, TQMap<TQString,TQString> *map) {
+   TDE_EXPORT bool add_konqsidebar_baghirasidebar(TQString* fn, TQString* param, TQMap<TQString,TQString> *map) {
       Q_UNUSED(param);
       
       map->insert("Type", "Link");
@@ -61,7 +61,7 @@ extern "C" {
 
 extern "C"
 {
-    KDE_EXPORT void* create_konqsidebar_baghirasidebar(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
+    TDE_EXPORT void* create_konqsidebar_baghirasidebar(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
     {
         return new baghiraSidebar(instance,par,widp,desktopname,name);
     }
