@@ -15,7 +15,7 @@ class TQListBoxItem;
 
 class baghiraSidebar : public KonqSidebarPlugin
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 public:
     /**
