@@ -44,12 +44,12 @@ ResizingLinkBox::ResizingLinkBox( TQWidget * parent, const char * name, WFlags f
    size_ = config.readNumEntry (TQString(name) + "_IconSize", 48);
    popupMenu = new TDEPopupMenu;
    popupMenu->insertTitle (i18n("Icon Size"),122,122);
-   popupMenu->insertItem("16x16", this, SLOT(setIconSize(int)),0,16,123);
-   popupMenu->insertItem("22x22", this, SLOT(setIconSize(int)),0,22,124);
-   popupMenu->insertItem("32x32", this, SLOT(setIconSize(int)),0,32,125);
-   popupMenu->insertItem("48x48", this, SLOT(setIconSize(int)),0,48,126);
-   popupMenu->insertItem("64x64", this, SLOT(setIconSize(int)),0,64,127);
-   popupMenu->insertItem("128x128", this, SLOT(setIconSize(int)),0,128,128);
+   popupMenu->insertItem("16x16", this, TQ_SLOT(setIconSize(int)),0,16,123);
+   popupMenu->insertItem("22x22", this, TQ_SLOT(setIconSize(int)),0,22,124);
+   popupMenu->insertItem("32x32", this, TQ_SLOT(setIconSize(int)),0,32,125);
+   popupMenu->insertItem("48x48", this, TQ_SLOT(setIconSize(int)),0,48,126);
+   popupMenu->insertItem("64x64", this, TQ_SLOT(setIconSize(int)),0,64,127);
+   popupMenu->insertItem("128x128", this, TQ_SLOT(setIconSize(int)),0,128,128);
 }
 
 void ResizingLinkBox::insertItem( const TQListBoxItem *lbi, int index )
@@ -145,7 +145,7 @@ MediaListBox::MediaListBox( TQWidget * parent, const char * name, WFlags f ) : R
 
    insertItem(new ListBoxDevice("system", size_, i18n("My Computer"), "system:/", "", "", TRUE, FALSE, FALSE));
    insertItem(new ListBoxDevice("network", size_, i18n("Network"), "remote:/", "", "", TRUE, FALSE, FALSE));
-   insertItem(new ListBoxDevice("hdd_mount", size_, i18n("Startvolume"), TQDir::rootDirPath(), "", "", TRUE, FALSE, FALSE));
+   insertItem(new ListBoxDevice("hdd-mounted", size_, i18n("Startvolume"), TQDir::rootDirPath(), "", "", TRUE, FALSE, FALSE));
    client = TDEApplication::dcopClient();
    client->connectDCOPSignal("kded", "mediamanager", "mediumAdded(TQString)", "BaghiraSidebarIface", "mediumAdded(TQString)", FALSE);
    client->connectDCOPSignal("kded", "mediamanager", "mediumRemoved(TQString)", "BaghiraSidebarIface", "mediumRemoved(const TQString)", FALSE);
@@ -274,7 +274,7 @@ ListBoxDevice *MediaListBox::createListBoxDevice(TQStringList & deviceProperties
       label = deviceProperties[MEDIALIST_PROPS*n+LABEL];
       label = i18n(label.section( " (", 0, 0 ).utf8());
    }
-   return new ListBoxDevice( icon, size_, label, "system:/media/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"), devicePopup->insertItem(deviceProperties[MEDIALIST_PROPS*n+NAME], this, SLOT(toggleDevice(int))));
+   return new ListBoxDevice( icon, size_, label, "system:/media/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"), devicePopup->insertItem(deviceProperties[MEDIALIST_PROPS*n+NAME], this, TQ_SLOT(toggleDevice(int))));
 }
 
 int MediaListBox::index (const TQString & name )
@@ -413,7 +413,7 @@ void MediaListBox::mousePressEvent ( TQMouseEvent *mpe )
       if (device && device->name().contains("fd"))
       {
          currentFloppy = device;
-         popupMenu->insertItem(i18n("Format disk..."), this, SLOT(kfloppy()),0,_FLOPPYID_,_FLOPPYINDEX_);
+         popupMenu->insertItem(i18n("Format disk..."), this, TQ_SLOT(kfloppy()),0,_FLOPPYID_,_FLOPPYINDEX_);
       }
       popupMenu->popup(mpe->globalPos());
       return;
@@ -451,7 +451,7 @@ ResizingLinkBox( parent, name, f), _poof(0), _poofIndex(0), _poofAnimPix(0), _po
 {
    setAcceptDrops(true);
    dialog = new LinkConfig();
-   connect(dialog->buttonOk, SIGNAL(clicked()), this, SLOT(updateLink()));
+   connect(dialog->buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(updateLink()));
    setCursor(TQt::PointingHandCursor);
 }
 
@@ -496,7 +496,7 @@ void DnDListBox::runPoof()
    _poof->erase();
    bitBlt(_poof, 0 ,0, _poofPix, 0, _poofIndex * _poofPix->width(), _poofPix->width(), _poofPix->width(), TQt::AndROP);
    ++_poofIndex;
-   TQTimer::singleShot ( 70, this, SLOT(runPoof()) ); // around 15 fps
+   TQTimer::singleShot ( 70, this, TQ_SLOT(runPoof()) ); // around 15 fps
 }
 
 void DnDListBox::dragEnterEvent ( TQDragEnterEvent *dee )
@@ -584,7 +584,7 @@ void DnDListBox::mousePressEvent ( TQMouseEvent *mpe )
       if (device)
       {
          currentItem = device;
-         popupMenu->insertItem("Edit link...", this, SLOT(configureLink()),0,0,0);
+         popupMenu->insertItem("Edit link...", this, TQ_SLOT(configureLink()),0,0,0);
       }
       popupMenu->popup(mpe->globalPos());
       return;
