@@ -227,9 +227,9 @@ void StartMenuButton::mouseReleaseEvent ( TQMouseEvent * mre)
       ((Panel*)parentWidget())->linkConfigDialog->title->setText(m_title);
       ((Panel*)parentWidget())->linkConfigDialog->command->setText(m_command);
       ((Panel*)parentWidget())->linkConfigDialog->icon->setIcon(m_icon);
-      disconnect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, SIGNAL(clicked()), 0, 0);
-      connect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, SIGNAL(clicked()), ((Panel*)parentWidget())->linkConfigDialog, SLOT(accept()));
-      connect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, SIGNAL(clicked()), this, SLOT(edit()));
+      disconnect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), 0, 0);
+      connect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), ((Panel*)parentWidget())->linkConfigDialog, TQ_SLOT(accept()));
+      connect(((Panel*)parentWidget())->linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(edit()));
       ((Panel*)parentWidget())->linkConfigDialog->exec();
    }
 }
@@ -843,7 +843,7 @@ void Panel::runPoof()
    _poof->erase();
    bitBlt(_poof, 0 ,0, _poofPix, 0, _poofIndex * _poofPix->width(), _poofPix->width(), _poofPix->width(), TQt::AndROP);
    ++_poofIndex;
-   TQTimer::singleShot ( 70, this, SLOT(runPoof()) ); // around 15 fps
+   TQTimer::singleShot ( 70, this, TQ_SLOT(runPoof()) ); // around 15 fps
 }
 
 void Panel::mouseReleaseEvent ( TQMouseEvent * mre )
@@ -855,9 +855,9 @@ void Panel::mouseReleaseEvent ( TQMouseEvent * mre )
       linkConfigDialog->title->clear();
       linkConfigDialog->command->clear();
       linkConfigDialog->icon->resetIcon();
-      disconnect(linkConfigDialog->buttonOk, SIGNAL(clicked()), 0, 0);
-      connect(linkConfigDialog->buttonOk, SIGNAL(clicked()), linkConfigDialog, SLOT(accept()));
-      connect(linkConfigDialog->buttonOk, SIGNAL(clicked()), this, SLOT(addIcon()));
+      disconnect(linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), 0, 0);
+      connect(linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), linkConfigDialog, TQ_SLOT(accept()));
+      connect(linkConfigDialog->buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(addIcon()));
       linkConfigDialog->exec();
    }
 }
@@ -1048,11 +1048,11 @@ StartMenuButton* Panel::addIcon ( TQString icon, TQString title, TQString comman
    // reposition icon
    repositionIcon(tmpButton, pt);
    // connections
-   connect (tmpButton, SIGNAL(hovered(const TQString &)), this, SIGNAL(message(const TQString &)));
-   connect (tmpButton, SIGNAL(unhovered()), this, SIGNAL(clearStatus()));
-   connect (tmpButton, SIGNAL(updateSize(int)), this, SLOT(updateSize(int)));
-   connect (tmpButton, SIGNAL(pressed(const TQString &)), parent(), SLOT(execute(const TQString &)));
-   connect (tmpButton, SIGNAL(pressed(const TQString &)), parent(), SLOT(close()));
+   connect (tmpButton, TQ_SIGNAL(hovered(const TQString &)), this, TQ_SIGNAL(message(const TQString &)));
+   connect (tmpButton, TQ_SIGNAL(unhovered()), this, TQ_SIGNAL(clearStatus()));
+   connect (tmpButton, TQ_SIGNAL(updateSize(int)), this, TQ_SLOT(updateSize(int)));
+   connect (tmpButton, TQ_SIGNAL(pressed(const TQString &)), parent(), TQ_SLOT(execute(const TQString &)));
+   connect (tmpButton, TQ_SIGNAL(pressed(const TQString &)), parent(), TQ_SLOT(close()));
    // done
    // inc counter
    _count++;
@@ -1082,8 +1082,8 @@ AppList::AppList(int size, TQWidget * parent) : TQScrollView(parent), _size(size
    setFrameStyle(TQFrame::LineEditPanel | TQFrame::Sunken );
    configDialog_ = new ConfigDialog;
    helpDialog_ = new HelpDialog;
-   connect (((TQObject*)configDialog_->buttonHelp), SIGNAL(clicked()), ((TQObject*)helpDialog_), SLOT(exec()));
-   connect (((TQObject*)configDialog_->buttonCancel), SIGNAL(clicked()), this, SLOT(unblockPopup()));
+   connect (((TQObject*)configDialog_->buttonHelp), TQ_SIGNAL(clicked()), ((TQObject*)helpDialog_), TQ_SLOT(exec()));
+   connect (((TQObject*)configDialog_->buttonCancel), TQ_SIGNAL(clicked()), this, TQ_SLOT(unblockPopup()));
    m_widget = new TQFrame(viewport());
    m_widget->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
    m_widget->setPaletteBackgroundColor(TDEGlobalSettings::baseColor());
@@ -1098,10 +1098,10 @@ AppList::AppList(int size, TQWidget * parent) : TQScrollView(parent), _size(size
    m_VLayout = new TQVBoxLayout(infoLayout);
    m_iconLoader = TDEGlobal::iconLoader();
    m_popup = new TDEPopupMenu(this);
-   m_popup->insertItem(i18n("Edit Entry"), this, SLOT(editDialog()));
-   m_popup->insertItem(i18n("Remove Entry"), this, SLOT(removeEntry()));
+   m_popup->insertItem(i18n("Edit Entry"), this, TQ_SLOT(editDialog()));
+   m_popup->insertItem(i18n("Remove Entry"), this, TQ_SLOT(removeEntry()));
    m_popup->insertSeparator();
-   m_popup->insertItem(i18n("Add Entry"), this, SLOT(addDialog()));
+   m_popup->insertItem(i18n("Add Entry"), this, TQ_SLOT(addDialog()));
    init();
 }
 
@@ -1132,8 +1132,8 @@ void AppList::reloadIcons( int size)
 
 void AppList::addDialog()
 {
-   disconnect (((TQObject*)configDialog_->buttonOk), SIGNAL(clicked()), this, 0);
-   connect (((TQObject*)configDialog_->buttonOk), SIGNAL(clicked()), this, SLOT(addEntry()));
+   disconnect (((TQObject*)configDialog_->buttonOk), TQ_SIGNAL(clicked()), this, 0);
+   connect (((TQObject*)configDialog_->buttonOk), TQ_SIGNAL(clicked()), this, TQ_SLOT(addEntry()));
    configDialog_->appName->clear();
    configDialog_->category->clearEdit();
    configDialog_->command->clear();
@@ -1195,8 +1195,8 @@ void AppList::editDialog()
    if (!handledEntry)
       return;
    popupBlocked_ = true;
-   disconnect (((TQObject*)configDialog_->buttonOk), SIGNAL(clicked()), this, 0);
-   connect (((TQObject*)configDialog_->buttonOk), SIGNAL(clicked()), this, SLOT(editEntry()));
+   disconnect (((TQObject*)configDialog_->buttonOk), TQ_SIGNAL(clicked()), this, 0);
+   connect (((TQObject*)configDialog_->buttonOk), TQ_SIGNAL(clicked()), this, TQ_SLOT(editEntry()));
    configDialog_->appName->setText(handledEntry->m_service->name());
    configDialog_->category->setCurrentItem (handledEntry->groupPath, false);
    configDialog_->showInSystray->setChecked( handledEntry->m_service->exec().contains("ksystraycmd ") );
@@ -1425,16 +1425,16 @@ void AppList::insertGroup(KServiceGroup *g, TQStringList & captions, TQStringLis
 StartMenuEntry* AppList::addApp(KService * s, TQStringList & captions, TQString relPath)
 {
    StartMenuEntry * tmp = new StartMenuEntry(s, relPath, _size, neewbieApps.find(s->desktopEntryName()) != neewbieApps.end(), m_widget);
-   connect (tmp, SIGNAL(appUp()), this, SLOT(appUp()));
-   connect (tmp, SIGNAL(appDown()), this, SLOT(appDown()));
-   connect (tmp, SIGNAL(appLeft()), this, SLOT(appLeft()));
-   connect (tmp, SIGNAL(hovered(const TQString&)), this, SIGNAL(message(const TQString&)));
-   if (useKTTS) connect (tmp, SIGNAL(sayText(const TQString&)), this, SIGNAL(sayText(const TQString&)));
-   connect (tmp, SIGNAL(unhovered()), this, SIGNAL(clearStatus()));
-   connect (tmp, SIGNAL(pressed()), parent(), SLOT(close()));
-   connect (tmp, SIGNAL(popup(StartMenuEntry*)), this, SLOT(popup(StartMenuEntry*)));
-   connect (tmp, SIGNAL(closeMenu()), parent(), SLOT(close()));
-   connect (tmp, SIGNAL(executed()), this, SLOT(sort()));
+   connect (tmp, TQ_SIGNAL(appUp()), this, TQ_SLOT(appUp()));
+   connect (tmp, TQ_SIGNAL(appDown()), this, TQ_SLOT(appDown()));
+   connect (tmp, TQ_SIGNAL(appLeft()), this, TQ_SLOT(appLeft()));
+   connect (tmp, TQ_SIGNAL(hovered(const TQString&)), this, TQ_SIGNAL(message(const TQString&)));
+   if (useKTTS) connect (tmp, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SIGNAL(sayText(const TQString&)));
+   connect (tmp, TQ_SIGNAL(unhovered()), this, TQ_SIGNAL(clearStatus()));
+   connect (tmp, TQ_SIGNAL(pressed()), parent(), TQ_SLOT(close()));
+   connect (tmp, TQ_SIGNAL(popup(StartMenuEntry*)), this, TQ_SLOT(popup(StartMenuEntry*)));
+   connect (tmp, TQ_SIGNAL(closeMenu()), parent(), TQ_SLOT(close()));
+   connect (tmp, TQ_SIGNAL(executed()), this, TQ_SLOT(sort()));
    m_VLayout->addWidget(tmp);
    tmp->hide();
    entryList.append(tmp);
@@ -1732,8 +1732,8 @@ StartMenu::StartMenu( int size, TQWidget * parent, WFlags f ) : TQWidget(parent,
    userButton = new StartMenuButton(_size, "folder_home", TQString(getenv("USER")), "~", StartMenuButton::Status, header, "_B_ALI_HEADER");
    headerLayout->addWidget(userButton);
    header->setPaletteBackgroundColor(TDEGlobalSettings::highlightColor());
-   connect (userButton, SIGNAL(pressed(const TQString &)), this, SLOT(execute(const TQString &)));
-   connect (userButton, SIGNAL(pressed(const TQString &)), this, SLOT(close()));
+   connect (userButton, TQ_SIGNAL(pressed(const TQString &)), this, TQ_SLOT(execute(const TQString &)));
+   connect (userButton, TQ_SIGNAL(pressed(const TQString &)), this, TQ_SLOT(close()));
    TQBoxLayout *mainLayout = new TQVBoxLayout();
    panelLayout->addLayout(mainLayout, 1, 1);
    mainLayout->addWidget(header);
@@ -1777,13 +1777,13 @@ StartMenu::StartMenu( int size, TQWidget * parent, WFlags f ) : TQWidget(parent,
       searchLine->completionObject()->insertItems(list);
    }
 
-   connect (categoryCombo, SIGNAL(activated( const TQString &)), appList, SLOT(showCategory(const TQString &)));
-   connect (searchLine, SIGNAL(typedTextChanged(const TQString &)), appList, SLOT(search(const TQString &)));
-   connect (searchLine, SIGNAL(textChanged(const TQString &)), this, SLOT(endHistory()));
-   connect (appList, SIGNAL(looseKey()), searchLine, SLOT(setFocus()));
-   connect (appList, SIGNAL(looseKey()), searchLine, SLOT(selectAll() ));
-   connect (kapp, SIGNAL(shutDown()), this, SLOT(save() ));
-   if (useKTTS) connect (appList, SIGNAL(sayText(const TQString&)), this, SLOT(sayText(const TQString&) ));
+   connect (categoryCombo, TQ_SIGNAL(activated( const TQString &)), appList, TQ_SLOT(showCategory(const TQString &)));
+   connect (searchLine, TQ_SIGNAL(typedTextChanged(const TQString &)), appList, TQ_SLOT(search(const TQString &)));
+   connect (searchLine, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(endHistory()));
+   connect (appList, TQ_SIGNAL(looseKey()), searchLine, TQ_SLOT(setFocus()));
+   connect (appList, TQ_SIGNAL(looseKey()), searchLine, TQ_SLOT(selectAll() ));
+   connect (kapp, TQ_SIGNAL(shutDown()), this, TQ_SLOT(save() ));
+   if (useKTTS) connect (appList, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SLOT(sayText(const TQString&) ));
 
    centerLayout->addWidget(appList,10);
    centerLayout->addSpacing ( 3 );
@@ -1796,10 +1796,10 @@ StartMenu::StartMenu( int size, TQWidget * parent, WFlags f ) : TQWidget(parent,
    TQFont tmpFnt = statusBar->font();
    tmpFnt.setBold(true);
    statusBar->setFont(tmpFnt);
-   connect (appList, SIGNAL(message(const TQString&)), this, SLOT(message(const TQString&) ));
-   connect (appList, SIGNAL(clearStatus()), this, SLOT(clearStatus() ));
-   connect (m_panel, SIGNAL(message(const TQString&)), this, SLOT(centerMessage(const TQString&) ));
-   connect (m_panel, SIGNAL(clearStatus()), this, SLOT(clearStatus() ));
+   connect (appList, TQ_SIGNAL(message(const TQString&)), this, TQ_SLOT(message(const TQString&) ));
+   connect (appList, TQ_SIGNAL(clearStatus()), this, TQ_SLOT(clearStatus() ));
+   connect (m_panel, TQ_SIGNAL(message(const TQString&)), this, TQ_SLOT(centerMessage(const TQString&) ));
+   connect (m_panel, TQ_SIGNAL(clearStatus()), this, TQ_SLOT(clearStatus() ));
    
    mainLayout->addSpacing ( 3 );
    mainLayout->addWidget ( statusBar );
@@ -1866,9 +1866,9 @@ void StartMenu::toggleKTTS(bool on)
       while( (runner = it.current()) != 0 )
       {
          ++it;
-         connect (runner, SIGNAL(sayText(const TQString&)), this, SIGNAL(sayText(const TQString&)));
+         connect (runner, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SIGNAL(sayText(const TQString&)));
       }
-      connect (appList, SIGNAL(sayText(const TQString&)), this, SLOT(sayText(const TQString&) ));
+      connect (appList, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SLOT(sayText(const TQString&) ));
    }
    else
    {
@@ -1877,9 +1877,9 @@ void StartMenu::toggleKTTS(bool on)
       while( (runner = it.current()) != 0 )
       {
          ++it;
-         disconnect (runner, SIGNAL(sayText(const TQString&)), this, SIGNAL(sayText(const TQString&)));
+         disconnect (runner, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SIGNAL(sayText(const TQString&)));
       }
-      disconnect (appList, SIGNAL(sayText(const TQString&)), this, SLOT(sayText(const TQString&) ));
+      disconnect (appList, TQ_SIGNAL(sayText(const TQString&)), this, TQ_SLOT(sayText(const TQString&) ));
    }
 }
 
@@ -2102,7 +2102,7 @@ void StartMenu::endHistory()
 
 void StartMenu::search(const TQString & string)
 {
-   disconnect (searchLine, SIGNAL(textChanged ( const TQString & )), this, SLOT(search(const TQString &)));
+   disconnect (searchLine, TQ_SIGNAL(textChanged ( const TQString & )), this, TQ_SLOT(search(const TQString &)));
    appList->search(string);
 }
 
@@ -2198,7 +2198,7 @@ bool StartMenu::eventFilter ( TQObject * o, TQEvent * e )
       case TQt::Key_Backspace:
       case TQt::Key_Delete:
       {
-         connect (le, SIGNAL(textChanged ( const TQString & )), this, SLOT(search(const TQString &)));
+         connect (le, TQ_SIGNAL(textChanged ( const TQString & )), this, TQ_SLOT(search(const TQString &)));
          break;
       }
       case TQt::Key_Down:
