@@ -473,7 +473,7 @@ bool starter::eventFilter( TQObject*, TQEvent *e )
 
 extern "C"
 {
-    KDE_EXPORT KPanelApplet* init( TQWidget *parent, const TQString& configFile)
+    TDE_EXPORT KPanelApplet* init( TQWidget *parent, const TQString& configFile)
     {
        TDEGlobal::locale()->insertCatalogue("baghira-starter");
        return new starter(configFile, KPanelApplet::Normal,
