@@ -725,7 +725,7 @@ void LiquidStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
 	{
 		w->setBackgroundMode( NoBackground );
 		installObjectEventHandler(ceData, elementFlags, ptr, this);
-                connect(w, SIGNAL(destroyed(TQObject*)), this, SLOT(progressBarDestroyed(TQObject*)));
+                connect(w, TQ_SIGNAL(destroyed(TQObject*)), this, TQ_SLOT(progressBarDestroyed(TQObject*)));
 		goto kstpolish;
 	}
 
